@@ -134,6 +134,7 @@ struct btd_device {
 
 	sdp_list_t	*tmp_records;
 
+	gboolean	paired;
 	gboolean	renewed_key;
 
 	gboolean	authorizing;
@@ -231,6 +232,10 @@ static void device_free(gpointer user_data)
 	g_slist_foreach(device->uuids, (GFunc) g_free, NULL);
 	g_slist_free(device->uuids);
 
+	if (device->tmp_records)
+		sdp_list_free(device->tmp_records,
+					(sdp_free_func_t) sdp_record_free);
+
 	if (device->disconn_timer)
 		g_source_remove(device->disconn_timer);
 
@@ -243,23 +248,7 @@ static void device_free(gpointer user_data)
 
 gboolean device_is_paired(struct btd_device *device)
 {
-	struct btd_adapter *adapter = device->adapter;
-	char filename[PATH_MAX + 1], *str;
-	char srcaddr[18], dstaddr[18];
-	gboolean ret;
-	bdaddr_t src;
-
-	adapter_get_address(adapter, &src);
-	ba2str(&src, srcaddr);
-	ba2str(&device->bdaddr, dstaddr);
-
-	create_name(filename, PATH_MAX, STORAGEDIR,
-			srcaddr, "linkkeys");
-	str = textfile_caseget(filename, dstaddr);
-	ret = str ? TRUE : FALSE;
-	g_free(str);
-
-	return ret;
+	return device->paired;
 }
 
 static DBusMessage *get_properties(DBusConnection *conn,
@@ -827,6 +816,11 @@ void device_remove_disconnect_watch(struct btd_device *device, guint id)
 	}
 }
 
+gboolean device_get_secmode3_conn(struct btd_device *device)
+{
+	return device->secmode3;
+}
+
 void device_set_secmode3_conn(struct btd_device *device, gboolean enable)
 {
 	device->secmode3 = enable;
@@ -868,6 +862,9 @@ struct btd_device *device_create(DBusConnection *conn,
 
 	device->auth = 0xff;
 
+	if (read_link_key(&src, &device->bdaddr, NULL, NULL) == 0)
+		device->paired = TRUE;
+
 	return btd_device_ref(device);
 }
 
@@ -899,6 +896,11 @@ void device_set_name(struct btd_device *device, const char *name)
 				DBUS_TYPE_STRING, &name);
 }
 
+void device_get_name(struct btd_device *device, char *name, size_t len)
+{
+	strncpy(name, device->name, len);
+}
+
 static void device_remove_bonding(struct btd_device *device)
 {
 	char filename[PATH_MAX + 1];
@@ -935,7 +937,8 @@ static void device_remove_stored(struct btd_device *device)
 
 	adapter_get_address(device->adapter, &src);
 	ba2str(&device->bdaddr, addr);
-	device_remove_bonding(device);
+	if (device->paired)
+		device_remove_bonding(device);
 	delete_entry(&src, "profiles", addr);
 	delete_entry(&src, "trusts", addr);
 }
@@ -1214,6 +1217,12 @@ static void update_services(struct browse_req *req, sdp_list_t *recs)
 		if (sdp_get_service_classes(rec, &svcclass) < 0)
 			continue;
 
+		/* Check for empty service classes list */
+		if (svcclass == NULL) {
+			debug("Skipping record with no service classes");
+			continue;
+		}
+
 		/* Extract the first element and skip the remainning */
 		profile_uuid = bt_uuid2string(svcclass->data);
 		if (!profile_uuid) {
@@ -1643,14 +1652,20 @@ static void bonding_request_free(struct bonding_req *bonding)
 	if (!device->agent)
 		return;
 
+	agent_cancel(device->agent);
 	agent_destroy(device->agent, FALSE);
 	device->agent = NULL;
 }
 
-static void device_set_paired(struct btd_device *device, gboolean value)
+void device_set_paired(struct btd_device *device, gboolean value)
 {
 	DBusConnection *conn = get_dbus_connection();
 
+	if (device->paired == value)
+		return;
+
+	device->paired = value;
+
 	emit_property_changed(conn, device->path, DEVICE_INTERFACE, "Paired",
 				DBUS_TYPE_BOOLEAN, &value);
 }
