@@ -3,7 +3,7 @@
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2006-2007  Nokia Corporation
- *  Copyright (C) 2004-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2009  Marcel Holtmann <marcel@holtmann.org>
  *  Copyright (C) 2007-2008  Fabien Chevalier <fabchevalier@free.fr>
  *
  *
@@ -27,10 +27,6 @@
 #include <config.h>
 #endif
 
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
-
 #include <gdbus.h>
 
 #include "error.h"
@@ -40,7 +36,6 @@ DBusHandlerResult error_common_reply(DBusConnection *conn, DBusMessage *msg,
 					const char *name, const char *descr)
 {
 	DBusMessage *derr;
-	dbus_bool_t ret;
 
 	if (!conn || !msg)
 		return DBUS_HANDLER_RESULT_HANDLED;
@@ -49,9 +44,7 @@ DBusHandlerResult error_common_reply(DBusConnection *conn, DBusMessage *msg,
 	if (!derr)
 		return DBUS_HANDLER_RESULT_NEED_MEMORY;
 
-	ret = dbus_connection_send(conn, derr, NULL);
-
-	dbus_message_unref(derr);
+	g_dbus_send_message(conn, derr);
 
 	return DBUS_HANDLER_RESULT_HANDLED;
 }
